@@ -41,11 +41,13 @@ class opensshStatus(hildondesktop.StatusMenuItem):
         self.skipSystemCheck = False
         if path.isfile("/home/user/.openssh-status-widget"):
             parser = SafeConfigParser()
-            parser.read('/home/user/.openssh-status-widget')
-            self.confirmDisconnect = parser.getboolean('options', 'confirmDisconnect')
-            self.stopTracking = parser.getboolean('options', 'stopTracking')
-            skipSystemCheck = parser.getboolean('options', 'skipSystemCheck')
-            print skipSystemCheck
+            try:
+                parser.read('/home/user/.openssh-status-widget')
+                self.confirmDisconnect = parser.getboolean('options', 'confirmDisconnect')
+                self.stopTracking = parser.getboolean('options', 'stopTracking')
+                skipSystemCheck = parser.getboolean('options', 'skipSystemCheck')
+            except:
+                subprocess.call(["sudo", "rm", "/home/user/.openssh-status-widget"])
             
         sshSystemStart = False
         sshSystemRespawn = False
